@@ -60,14 +60,6 @@ class GlycanProviderTests(unittest.TestCase):
         logger.info("riD (%d)", len(riD))
         ok = gP.testCache(minCount=minCount)
         self.assertTrue(ok)
-        ok = gP.toStash(self.__stashUrl, self.__stashRemotePath)
-        self.assertTrue(ok)
-        ok = gP.fromStash(self.__stashUrl, self.__stashRemotePath)
-        self.assertTrue(ok)
-        ok = gP.reload()
-        self.assertTrue(ok)
-        ok = gP.testCache(minCount=minCount)
-        self.assertTrue(ok)
         gP = GlycanProvider(cachePath=self.__cachePath, useCache=True)
         ok = gP.testCache(minCount=minCount)
         self.assertTrue(ok)
@@ -77,12 +69,6 @@ class GlycanProviderTests(unittest.TestCase):
         minCount = 12
         configName = "site_info_remote_configuration"
         cfgOb = ConfigUtil(configPath=self.__configPath, defaultSectionName=configName, mockTopPath=self.__mockTopPath)
-        userName = cfgOb.get("_STASH_AUTH_USERNAME", sectionName=configName)
-        password = cfgOb.get("_STASH_AUTH_PASSWORD", sectionName=configName)
-        basePath = cfgOb.get("_STASH_SERVER_BASE_PATH", sectionName=configName)
-        url = cfgOb.get("STASH_SERVER_URL", sectionName=configName)
-        urlFallBack = cfgOb.get("STASH_SERVER_FALLBACK_URL", sectionName=configName)
-        #
         gP = GlycanProvider(cachePath=self.__cachePath, useCache=True)
         ok = gP.testCache(minCount=minCount)
         ok = gP.update(cfgOb, fmt="json", indent=3)
@@ -90,14 +76,9 @@ class GlycanProviderTests(unittest.TestCase):
         riD = gP.getIdentifiers()
         logger.info("riD (%d)", len(riD))
         self.assertTrue(ok)
-        ok = gP.toStash(url, basePath, userName=userName, password=password)
+        ok = gP.backup(cfgOb, configName)
         self.assertTrue(ok)
-        gP.toStash(urlFallBack, basePath, userName=userName, password=password)
-        self.assertTrue(ok)
-        #
-        ok = gP.fromStash(url, basePath, userName=userName, password=password)
-        self.assertTrue(ok)
-        ok = gP.fromStash(urlFallBack, basePath, userName=userName, password=password)
+        ok = gP.restore(cfgOb, configName)
         self.assertTrue(ok)
         #
         ok = gP.update(cfgOb, fmt="json", indent=3)
