@@ -10,7 +10,7 @@
 Tests for extractor selected values from collections (limited tests from mock-data repos)
 """
 
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
@@ -116,7 +116,7 @@ class ObjectExtractorTests(unittest.TestCase):
             )
             eCount = obEx.getCount()
             logger.info("Entry count ifs %d", eCount)
-            self.assertGreaterEqual(eCount, 14)
+            self.assertGreaterEqual(eCount, 6)
         except Exception as e:
             logger.exception("Failing with %s", str(e))
             self.fail()
