@@ -9,7 +9,7 @@
 """
 Tests for extraction of polymer entity sequence details from the ExDB core collections.
 """
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
@@ -63,7 +63,8 @@ class PolymerEntityExtractorTests(unittest.TestCase):
         try:
             pEx = PolymerEntityExtractor(self.__cfgOb)
             pD, _ = pEx.getProteinSequenceDetails()
-            self.assertGreaterEqual(len(pD), 200)
+            #
+            self.assertGreaterEqual(len(pD), 100)
             logger.info("Polymer entity count %d", len(pD))
         except Exception as e:
             logger.exception("Failing with %s", str(e))
